@@ -1,6 +1,6 @@
 confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho, gamma2, phi, digits, transf, targs, verbose=FALSE, control, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(object), must="rma.mv")
 
@@ -30,12 +30,12 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
    if (missing(control))
       control <- list()
 
-   level <- ifelse(level == 0, 1, ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)))
-
    ddd <- list(...)
 
    .chkdots(ddd, c("time", "xlim", "extint"))
 
+   level <- .level(level, stopon100=.isTRUE(ddd$extint))
+
    if (.isTRUE(ddd$time))
       time.start <- proc.time()
 
@@ -156,7 +156,7 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
 
    if (random) {
 
-      type <- "PL"
+      type <- "pl"
 
       ######################################################################
 
@@ -203,19 +203,19 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
       ### check if user specified a logical
 
       if (!missing(sigma2) && is.logical(sigma2))
-         stop(mstyle$stop("Must specify the number for the 'sigma2' component."))
+         stop(mstyle$stop("Must specify a number for the 'sigma2' component."))
 
       if (!missing(tau2) && is.logical(tau2))
-         stop(mstyle$stop("Must specify the number for the 'tau2' component."))
+         stop(mstyle$stop("Must specify a number for the 'tau2' component."))
 
       if (!missing(rho) && is.logical(rho))
-         stop(mstyle$stop("Must specify the number for the 'rho' component."))
+         stop(mstyle$stop("Must specify a number for the 'rho' component."))
 
       if (!missing(gamma2) && is.logical(gamma2))
-         stop(mstyle$stop("Must specify the number for the 'gamma2' component."))
+         stop(mstyle$stop("Must specify a number for the 'gamma2' component."))
 
       if (!missing(phi) && is.logical(phi))
-         stop(mstyle$stop("Must specify the number for the 'phi' component."))
+         stop(mstyle$stop("Must specify a number for the 'phi' component."))
 
       ### check if user specified a component that does not exist
 
@@ -253,11 +253,11 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
 
       ### if everything is good so far, get value of the variance component and set 'comp'
 
-      sigma2.pos <- NA
-      tau2.pos   <- NA
-      rho.pos    <- NA
-      gamma2.pos <- NA
-      phi.pos    <- NA
+      sigma2.pos <- NA_integer_
+      tau2.pos   <- NA_integer_
+      rho.pos    <- NA_integer_
+      gamma2.pos <- NA_integer_
+      phi.pos    <- NA_integer_
 
       if (!missing(sigma2)) {
          vc <- x$sigma2[sigma2]
@@ -304,15 +304,15 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
       }
       if (comp == "rho") {
          if (is.element(x$struct[1], c("CS","HCS")))
-            con$vc.min <- -1                                  ### this will fail most of the time but with retries, this may get closer to actual lower bound
-            #con$vc.min <- min(-1/(x$g.nlevels.f[1] - 1), vc) ### this guarantees that cor matrix is semi-positive definite, but since V gets added, this is actually too strict
+            con$vc.min <- -1                                  # this will fail most of the time but with retries, this may get closer to actual lower bound
+            #con$vc.min <- min(-1/(x$g.nlevels.f[1] - 1), vc) # this guarantees that cor matrix is semi-positive definite, but since V gets added, this is actually too strict
          if (is.element(x$struct[1], c("AR","HAR","CAR")))
-            con$vc.min <- min(0, vc)                          ### negative autocorrelation parameters not considered (not even sensible for CAR)
+            con$vc.min <- min(0, vc)                          # negative autocorrelation parameters not considered (not even sensible for CAR)
          if (is.element(x$struct[1], c("UN","UNR","GEN")))
-            con$vc.min <- -1                                  ### TODO: this will often fail! (but with retries, this should still work)
+            con$vc.min <- -1                                  # TODO: this will often fail! (but with retries, this should still work)
          con$vc.max <- 1
          if (is.element(x$struct[1], c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH"))) {
-            con$vc.min <- 0                                   ### TODO: 0 basically always fails
+            con$vc.min <- 0                                   # TODO: 0 basically always fails
             con$vc.max <- max(10, vc*10)
          }
          if (is.element(x$struct[1], c("PHYPL","PHYPD"))) {
@@ -322,15 +322,15 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
       }
       if (comp == "phi") {
          if (is.element(x$struct[2], c("CS","HCS")))
-            con$vc.min <- -1                                  ### this will fail most of the time but with retries, this may get closer to actual lower bound
-            #con$vc.min <- min(-1/(x$h.nlevels.f[1] - 1), vc) ### this guarantees that cor matrix is semi-positive definite, but since V gets added, this is actually too strict
+            con$vc.min <- -1                                  # this will fail most of the time but with retries, this may get closer to actual lower bound
+            #con$vc.min <- min(-1/(x$h.nlevels.f[1] - 1), vc) # this guarantees that cor matrix is semi-positive definite, but since V gets added, this is actually too strict
          if (is.element(x$struct[2], c("AR","HAR","CAR")))
-            con$vc.min <- min(0, vc)                          ### negative autocorrelation parameters not considered (not even sensible for CAR)
+            con$vc.min <- min(0, vc)                          # negative autocorrelation parameters not considered (not even sensible for CAR)
          if (is.element(x$struct[2], c("UN","UNR","GEN")))
-            con$vc.min <- -1                                  ### TODO: this will often fail! (but with retries, this should still work)
+            con$vc.min <- -1                                  # TODO: this will often fail! (but with retries, this should still work)
          con$vc.max <- 1
          if (is.element(x$struct[2], c("SPEXP","SPGAU","SPLIN","SPRAT","SPSPH"))) {
-            con$vc.min <- 0                                   ### TODO: 0 basically always fails
+            con$vc.min <- 0                                   # TODO: 0 basically always fails
             con$vc.max <- max(10, vc*10)
          }
          if (is.element(x$struct[2], c("PHYPL","PHYPD"))) {
@@ -349,13 +349,13 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
 
       ######################################################################
 
-      vc.lb <- NA
-      vc.ub <- NA
-      ci.null <- FALSE ### logical if CI is a null set
-      lb.conv <- FALSE ### logical if search converged for lower bound (LB)
-      ub.conv <- FALSE ### logical if search converged for upper bound (UB)
-      lb.sign <- ""    ### for sign in case LB must be below vc.min ("<") or above vc.max (">")
-      ub.sign <- ""    ### for sign in case UB must be below vc.min ("<") or above vc.max (">")
+      vc.lb <- NA_real_
+      vc.ub <- NA_real_
+      ci.null <- FALSE # logical if CI is a null set
+      lb.conv <- FALSE # logical if search converged for lower bound (LB)
+      ub.conv <- FALSE # logical if search converged for upper bound (UB)
+      lb.sign <- ""    # for sign in case LB must be below vc.min ("<") or above vc.max (">")
+      ub.sign <- ""    # for sign in case UB must be below vc.min ("<") or above vc.max (">")
 
       ######################################################################
       ######################################################################
@@ -363,7 +363,7 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
 
       ### Profile Likelihood method
 
-      if (type == "PL") {
+      if (type == "pl") {
 
          if (con$vc.min > vc)
             stop(mstyle$stop("Lower bound of interval to be searched must be <= estimated value of component."))
@@ -410,6 +410,7 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
                   }
 
                   ### check if uniroot method converged
+
                   if (!inherits(res, "try-error")) {
                      vc.lb <- res
                      lb.conv <- TRUE
@@ -466,6 +467,7 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
                   }
 
                   ### check if uniroot method converged
+
                   if (!inherits(res, "try-error")) {
                      vc.ub <- res
                      ub.conv <- TRUE
@@ -500,7 +502,7 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
       vc <- c(vc, vc.lb, vc.ub)
 
       if (is.element(comp, c("sigma2", "tau2", "gamma2"))) {
-         vcsqrt <- sqrt(ifelse(vc >= 0, vc, NA))
+         vcsqrt <- sqrt(ifelse(vc >= 0, vc, NA_real_))
          res.random <- rbind(vc, vcsqrt)
          if (comp == "sigma2") {
             if (length(x$sigma2) == 1L) {
@@ -551,8 +553,8 @@ confint.rma.mv <- function(object, parm, level, fixed=FALSE, sigma2, tau2, rho,
 
    if (fixed) {
 
-      if (x$test == "t") {
-         crit <- sapply(seq_along(x$ddf), function(j) if (x$ddf[j] > 0) qt(level/2, df=x$ddf[j], lower.tail=FALSE) else NA)
+      if (is.element(x$test, c("knha","adhoc","t"))) {
+         crit <- sapply(seq_along(x$ddf), function(j) if (x$ddf[j] > 0) qt(level/2, df=x$ddf[j], lower.tail=FALSE) else NA_real_)
       } else {
          crit <- qnorm(level/2, lower.tail=FALSE)
       }
