@@ -1,6 +1,6 @@
-dfbetas.rma.mv <- function(model, progbar=FALSE, cluster, reestimate=TRUE, parallel="no", ncpus=1, cl=NULL, ...) {
+dfbetas.rma.mv <- function(model, progbar=FALSE, cluster, reestimate=TRUE, parallel="no", ncpus=1, cl, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(model), must="rma.mv", notav="robust.rma")
 
@@ -16,6 +16,9 @@ dfbetas.rma.mv <- function(model, progbar=FALSE, cluster, reestimate=TRUE, paral
    if (parallel == "no" && ncpus > 1)
       parallel <- "snow"
 
+   if (missing(cl))
+      cl <- NULL
+
    if (!is.null(cl) && inherits(cl, "SOCKcluster")) {
       parallel <- "snow"
       ncpus <- length(cl)
@@ -38,13 +41,17 @@ dfbetas.rma.mv <- function(model, progbar=FALSE, cluster, reestimate=TRUE, paral
 
    if (!progbar) {
       pbo <- pbapply::pboptions(type="none")
-      on.exit(pbapply::pboptions(pbo))
+      on.exit(pbapply::pboptions(pbo), add=TRUE)
    }
 
    misscluster <- ifelse(missing(cluster), TRUE, FALSE)
 
-   if (misscluster)
+   if (misscluster) {
       cluster <- seq_len(x$k.all)
+   } else {
+      mf <- match.call()
+      cluster <- .getx("cluster", mf=mf, data=x$data)
+   }
 
    ddd <- list(...)
 
@@ -57,13 +64,14 @@ dfbetas.rma.mv <- function(model, progbar=FALSE, cluster, reestimate=TRUE, paral
 
    ### process cluster variable
 
-   # note: cluster variable is assumed to be of the same length as the size of
-   # the original dataset passed to the model fitting function and so we apply
-   # the same subsetting and removing of missings (if necessary) as was done
-   # during model fitting
+   ### note: cluster variable must be of the same length as the original dataset
+   ###       so we have to apply the same subsetting (if necessary) and removing
+   ###       of NAs as was done during model fitting
 
-   if (!is.null(x$subset))
-      cluster <- cluster[x$subset]
+   if (length(cluster) != x$k.all)
+      stop(mstyle$stop(paste0("Length of variable specified via 'cluster' (", length(cluster), ") does not match length of data (", x$k.all, ").")))
+
+   cluster <- .getsubset(cluster, x$subset)
 
    cluster.f <- cluster
 
@@ -77,9 +85,6 @@ dfbetas.rma.mv <- function(model, progbar=FALSE, cluster, reestimate=TRUE, paral
    if (length(cluster.f) == 0L)
       stop(mstyle$stop(paste0("Cannot find 'cluster' variable (or it has zero length).")))
 
-   if (length(cluster) != x$k)
-      stop(mstyle$stop(paste0("Length of variable specified via 'cluster' (", length(cluster), ") does not match length of data (", x$k, ").")))
-
    ### cluster ids and number of clusters
 
    ids <- unique(cluster)
