@@ -1,13 +1,13 @@
 rma.mh   <- function(ai, bi, ci, di, n1i, n2i, x1i, x2i, t1i, t2i, measure="OR",
 data, slab, subset,
-add=1/2, to="only0", drop00=TRUE, ### for add/to/drop00, 1st element for escalc(), 2nd for MH method
+add=1/2, to="only0", drop00=TRUE, # for add/to/drop00, 1st element for escalc(), 2nd for MH method
 correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
    #########################################################################
 
    ###### setup
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    ### check argument specifications
 
@@ -53,9 +53,9 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
    ### set defaults or get onlyo1, addyi, and addvi arguments
 
-   onlyo1 <- ifelse(is.null(ddd$onlyo1), FALSE, ddd$onlyo1)
-   addyi  <- ifelse(is.null(ddd$addyi),  TRUE,  ddd$addyi)
-   addvi  <- ifelse(is.null(ddd$addvi),  TRUE,  ddd$addvi)
+   onlyo1 <- .chkddd(ddd$onlyo1, FALSE)
+   addyi  <- .chkddd(ddd$addyi,  TRUE)
+   addvi  <- .chkddd(ddd$addvi,  TRUE)
 
    ### set defaults for digits
 
@@ -104,7 +104,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
    if (is.element(measure, c("RR","OR","RD"))) {
 
-      x1i <- x2i <- t1i <- t2i <- NA
+      x1i <- x2i <- t1i <- t2i <- NA_real_
 
       ai  <- .getx("ai",  mf=mf, data=data, checknumeric=TRUE)
       bi  <- .getx("bi",  mf=mf, data=data, checknumeric=TRUE)
@@ -117,7 +117,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       if (is.null(di)) di <- n2i - ci
       ni <- ai + bi + ci + di
 
-      k <- length(ai) ### number of outcomes before subsetting
+      k <- length(ai) # number of outcomes before subsetting
       k.all <- k
 
       if (length(ai)==0L || length(bi)==0L || length(ci)==0L || length(di)==0L)
@@ -179,18 +179,18 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       ### calculate observed effect estimates and sampling variances
 
       dat <- .do.call(escalc, measure=measure, ai=ai, bi=bi, ci=ci, di=di, add=add[1], to=to[1], drop00=drop00[1], onlyo1=onlyo1, addyi=addyi, addvi=addvi)
-      yi <- dat$yi ### one or more yi/vi pairs may be NA/NA
-      vi <- dat$vi ### one or more yi/vi pairs may be NA/NA
+      yi <- dat$yi # one or more yi/vi pairs may be NA/NA
+      vi <- dat$vi # one or more yi/vi pairs may be NA/NA
 
       ### if drop00[2]=TRUE, set counts to NA for studies that have no events (or all events) in both arms
 
       if (drop00[2]) {
          id00 <- c(ai == 0L & ci == 0L) | c(bi == 0L & di == 0L)
          id00[is.na(id00)] <- FALSE
-         ai[id00] <- NA
-         bi[id00] <- NA
-         ci[id00] <- NA
-         di[id00] <- NA
+         ai[id00] <- NA_real_
+         bi[id00] <- NA_real_
+         ci[id00] <- NA_real_
+         di[id00] <- NA_real_
       }
 
       ### save the actual cell frequencies and yi/vi values (including potential NAs)
@@ -201,7 +201,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       vi.f <- vi
       ni.f <- ni
 
-      k.f <- k ### total number of tables including all NAs
+      k.f <- k # total number of tables including all NAs
 
       ### check for NAs in table data and act accordingly
 
@@ -219,7 +219,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
             ci <- ci[not.na]
             di <- di[not.na]
             k  <- length(ai)
-            warning(mstyle$warning("Tables with NAs omitted from model fitting."), call.=FALSE)
+            warning(mstyle$warning(paste(sum(has.na), ifelse(sum(has.na) > 1, "studies", "study"), "with NAs omitted from model fitting.")), call.=FALSE)
          }
 
          if (na.act == "na.fail")
@@ -249,8 +249,8 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
             ni <- ni[not.na.yivi]
             warning(mstyle$warning("Some yi/vi values are NA."), call.=FALSE)
 
-            attr(yi, "measure") <- measure ### add measure attribute back
-            attr(yi, "ni")      <- ni      ### add ni attribute back
+            attr(yi, "measure") <- measure # add measure attribute back
+            attr(yi, "ni")      <- ni      # add ni attribute back
 
          }
 
@@ -259,7 +259,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
       }
 
-      k.yi <- length(yi) ### number of yi/vi pairs that are not NA (needed for QE df and fit.stats calculation)
+      k.yi <- length(yi) # number of yi/vi pairs that are not NA (needed for QE df and fit.stats calculation)
 
       ### add/to procedures for the 2x2 tables for the actual meta-analysis
       ### note: technically, nothing needs to be added, but Stata/RevMan add 1/2 by default for only0 studies (but drop studies with no/all events)
@@ -317,16 +317,16 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
    if (is.element(measure, c("IRR","IRD"))) {
 
-      ai <- bi <- ci <- di <- NA
+      ai <- bi <- ci <- di <- NA_real_
 
-      x1i <- .getx("x1i", mf=mf, data=data)
-      x2i <- .getx("x2i", mf=mf, data=data)
-      t1i <- .getx("t1i", mf=mf, data=data)
-      t2i <- .getx("t2i", mf=mf, data=data)
+      x1i <- .getx("x1i", mf=mf, data=data, checknumeric=TRUE)
+      x2i <- .getx("x2i", mf=mf, data=data, checknumeric=TRUE)
+      t1i <- .getx("t1i", mf=mf, data=data, checknumeric=TRUE)
+      t2i <- .getx("t2i", mf=mf, data=data, checknumeric=TRUE)
 
       ni  <- t1i + t2i
 
-      k <- length(x1i) ### number of outcomes before subsetting
+      k <- length(x1i) # number of outcomes before subsetting
       k.all <- k
 
       if (length(x1i)==0L || length(x2i)==0L || length(t1i)==0L || length(t2i)==0L)
@@ -385,16 +385,16 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       ### calculate observed effect estimates and sampling variances
 
       dat <- .do.call(escalc, measure=measure, x1i=x1i, x2i=x2i, t1i=t1i, t2i=t2i, add=add[1], to=to[1], drop00=drop00[1], onlyo1=onlyo1, addyi=addyi, addvi=addvi)
-      yi  <- dat$yi ### one or more yi/vi pairs may be NA/NA
-      vi  <- dat$vi ### one or more yi/vi pairs may be NA/NA
+      yi  <- dat$yi # one or more yi/vi pairs may be NA/NA
+      vi  <- dat$vi # one or more yi/vi pairs may be NA/NA
 
       ### if drop00[2]=TRUE, set counts to NA for studies that have no events in both arms
 
       if (drop00[2]) {
          id00 <- c(x1i == 0L & x2i == 0L)
          id00[is.na(id00)] <- FALSE
-         x1i[id00] <- NA
-         x2i[id00] <- NA
+         x1i[id00] <- NA_real_
+         x2i[id00] <- NA_real_
       }
 
       ### save the actual cell frequencies and yi/vi values (including potential NAs)
@@ -405,7 +405,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       vi.f <- vi
       ni.f <- ni
 
-      k.f <- k ### total number of tables including all NAs
+      k.f <- k # total number of tables including all NAs
 
       ### check for NAs in table data and act accordingly
 
@@ -423,7 +423,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
             t1i  <- t1i[not.na]
             t2i  <- t2i[not.na]
             k    <- length(x1i)
-            warning(mstyle$warning("Tables with NAs omitted from model fitting."), call.=FALSE)
+            warning(mstyle$warning(paste(sum(has.na), ifelse(sum(has.na) > 1, "studies", "study"), "with NAs omitted from model fitting.")), call.=FALSE)
          }
 
          if (na.act == "na.fail")
@@ -453,8 +453,8 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
             ni <- ni[not.na.yivi]
             warning(mstyle$warning("Some yi/vi values are NA."), call.=FALSE)
 
-            attr(yi, "measure") <- measure ### add measure attribute back
-            attr(yi, "ni")      <- ni      ### add ni attribute back
+            attr(yi, "measure") <- measure # add measure attribute back
+            attr(yi, "ni")      <- ni      # add ni attribute back
 
          }
 
@@ -463,7 +463,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
       }
 
-      k.yi <- length(yi) ### number of yi/vi pairs that are not NA (needed for QE df and fitstats calculation)
+      k.yi <- length(yi) # number of yi/vi pairs that are not NA (needed for QE df and fitstats calculation)
 
       ### add/to procedures for the 2x2 tables for the actual meta-analysis
       ### note: technically, nothing needs to be added
@@ -511,7 +511,8 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
    level <- .level(level)
 
-   CO <- COp <- MH <- MHp <- BD <- BDp <- TA <- TAp <- k.pos <- NA
+   CO <- COp <- MH <- MHp <- BD <- BDp <- TA <- TAp <- NA_real_
+   k.pos <- NA_integer_
 
    ###### model fitting, test statistics, and confidence intervals
 
@@ -528,17 +529,17 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       S  <- sum(Si)
 
       if (identical(R,0) || identical(S,0) || identical(R,0L) || identical(S,0L)) {
-         beta.exp <- NA
-         beta     <- NA
-         se       <- NA
-         zval     <- NA
-         pval     <- NA
-         ci.lb    <- NA
-         ci.ub    <- NA
+         beta.exp <- NA_real_
+         beta     <- NA_real_
+         se       <- NA_real_
+         zval     <- NA_real_
+         pval     <- NA_real_
+         ci.lb    <- NA_real_
+         ci.ub    <- NA_real_
       } else {
          beta.exp <- R/S
          beta     <- log(beta.exp)
-         se       <- sqrt(1/2 * (sum(Pi*Ri)/R^2 + sum(Pi*Si + Qi*Ri)/(R*S) + sum(Qi*Si)/S^2)) ### based on Robins et al. (1986)
+         se       <- sqrt(1/2 * (sum(Pi*Ri)/R^2 + sum(Pi*Si + Qi*Ri)/(R*S) + sum(Qi*Si)/S^2)) # based on Robins et al. (1986)
          zval     <- beta / se
          pval     <- 2*pnorm(abs(zval), lower.tail=FALSE)
          ci.lb    <- beta - qnorm(level/2, lower.tail=FALSE) * se
@@ -554,10 +555,10 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       yt <- bi + di
 
       if (identical(sum(xt),0) || identical(sum(yt),0) || identical(sum(xt),0L) || identical(sum(yt),0L)) {
-         CO  <- NA
-         COp <- NA
-         MH  <- NA
-         MHp <- NA
+         CO  <- NA_real_
+         COp <- NA_real_
+         MH  <- NA_real_
+         MHp <- NA_real_
       } else {
          CO  <- (abs(sum(ai - (n1i/Ni)*xt)) - ifelse(correct, 0.5, 0))^2 / sum((n1i/Ni)*(n2i/Ni)*(xt*(yt/Ni)))
          COp <- pchisq(CO, df=1, lower.tail=FALSE)
@@ -568,11 +569,11 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       ### Breslow-Day and Tarone's Test for Heterogeneity
 
       if (is.na(beta)) {
-         BD    <- NA
-         TA    <- NA
-         BDp   <- NA
-         TAp   <- NA
-         k.pos <- 0
+         BD    <- NA_real_
+         TA    <- NA_real_
+         BDp   <- NA_real_
+         TAp   <- NA_real_
+         k.pos <- 0L
       } else {
          if (identical(beta.exp,1) || identical(beta.exp,1L)) {
             N11 <- (n1i/Ni)*xt
@@ -589,12 +590,12 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
          N22   <- N11 - n1i[pos] - xt[pos] + Ni[pos]
          BD    <- max(0, sum((ai[pos]-N11)^2 / (1/N11 + 1/N12 + 1/N21 + 1/N22)^(-1)))
          TA    <- max(0, BD - sum(ai[pos]-N11)^2 / sum((1/N11 + 1/N12 + 1/N21 + 1/N22)^(-1)))
-         if (k.pos > 1) {
-            BDp <- pchisq(BD, df=k.pos-1, lower.tail=FALSE)
-            TAp <- pchisq(TA, df=k.pos-1, lower.tail=FALSE)
+         if (k.pos > 1L) {
+            BDp <- pchisq(BD, df=k.pos-1L, lower.tail=FALSE)
+            TAp <- pchisq(TA, df=k.pos-1L, lower.tail=FALSE)
          } else {
-            BDp <- NA
-            TAp <- NA
+            BDp <- NA_real_
+            TAp <- NA_real_
          }
       }
 
@@ -606,13 +607,13 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       S <- sum(ci * (n1i/Ni))
 
       if (identical(sum(ai),0) || identical(sum(ci),0) || identical(sum(ai),0L) || identical(sum(ci),0L)) {
-         beta.exp <- NA
-         beta     <- NA
-         se       <- NA
-         zval     <- NA
-         pval     <- NA
-         ci.lb    <- NA
-         ci.ub    <- NA
+         beta.exp <- NA_real_
+         beta     <- NA_real_
+         se       <- NA_real_
+         zval     <- NA_real_
+         pval     <- NA_real_
+         ci.lb    <- NA_real_
+         ci.ub    <- NA_real_
       } else {
          beta.exp <- R/S
          beta     <- log(beta.exp)
@@ -631,8 +632,8 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
    if (measure == "RD") {
 
       beta  <- sum(ai*(n2i/Ni) - ci*(n1i/Ni)) / sum(n1i*(n2i/Ni))
-      se    <- sqrt((beta * (sum(ci*(n1i/Ni)^2 - ai*(n2i/Ni)^2 + (n1i/Ni)*(n2i/Ni)*(n2i-n1i)/2)) + sum(ai*(n2i-ci)/Ni + ci*(n1i-ai)/Ni)/2) / sum(n1i*(n2i/Ni))^2) ### equation in: Sato, Greenland, & Robins (1989)
-      #se   <- sqrt(sum(((ai/Ni^2)*bi*(n2i^2/n1i) + (ci/Ni^2)*di*(n1i^2/n2i))) / sum(n1i*(n2i/Ni))^2) ### equation in: Greenland & Robins (1985)
+      se    <- sqrt((beta * (sum(ci*(n1i/Ni)^2 - ai*(n2i/Ni)^2 + (n1i/Ni)*(n2i/Ni)*(n2i-n1i)/2)) + sum(ai*(n2i-ci)/Ni + ci*(n1i-ai)/Ni)/2) / sum(n1i*(n2i/Ni))^2) # equation in: Sato, Greenland, & Robins (1989)
+      #se   <- sqrt(sum(((ai/Ni^2)*bi*(n2i^2/n1i) + (ci/Ni^2)*di*(n1i^2/n2i))) / sum(n1i*(n2i/Ni))^2) # equation in: Greenland & Robins (1985)
       zval  <- beta / se
       pval  <- 2*pnorm(abs(zval), lower.tail=FALSE)
       ci.lb <- beta - qnorm(level/2, lower.tail=FALSE) * se
@@ -649,13 +650,13 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       S <- sum(x2i * (t1i/Ti))
 
       if (identical(sum(x1i),0) || identical(sum(x2i),0) || identical(sum(x1i),0L) || identical(sum(x2i),0L)) {
-         beta.exp <- NA
-         beta     <- NA
-         se       <- NA
-         zval     <- NA
-         pval     <- NA
-         ci.lb    <- NA
-         ci.ub    <- NA
+         beta.exp <- NA_real_
+         beta     <- NA_real_
+         se       <- NA_real_
+         zval     <- NA_real_
+         pval     <- NA_real_
+         ci.lb    <- NA_real_
+         ci.ub    <- NA_real_
       } else {
          beta.exp <- R/S
          beta     <- log(beta.exp)
@@ -673,8 +674,8 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
 
       xt <- x1i + x2i
       if (identical(sum(xt),0) || identical(sum(xt),0L)) {
-         MH  <- NA
-         MHp <- NA
+         MH  <- NA_real_
+         MHp <- NA_real_
       } else {
          MH  <- (abs(sum(x1i - xt*(t1i/Ti))) - ifelse(correct, 0.5, 0))^2 / sum(xt*(t1i/Ti)*(t2i/Ti))
          MHp <- pchisq(MH, df=1, lower.tail=FALSE)
@@ -685,7 +686,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
    if (measure == "IRD") {
 
       beta  <- sum((x1i*t2i - x2i*t1i)/Ti) / sum((t1i/Ti)*t2i)
-      se    <- sqrt(sum(((t1i/Ti)*t2i)^2*(x1i/t1i^2+x2i/t2i^2))) / sum((t1i/Ti)*t2i) ### from Rothland et al. (2008), chapter 15
+      se    <- sqrt(sum(((t1i/Ti)*t2i)^2*(x1i/t1i^2+x2i/t2i^2))) / sum((t1i/Ti)*t2i) # from Rothland et al. (2008), chapter 15
       zval  <- beta / se
       pval  <- 2*pnorm(abs(zval), lower.tail=FALSE)
       ci.lb <- beta - qnorm(level/2, lower.tail=FALSE) * se
@@ -722,7 +723,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
    ###### fit statistics
 
    if (verbose)
-      message(mstyle$message("Computing fit statistics and log likelihood ..."))
+      message(mstyle$message("Computing fit statistics and log-likelihood ..."))
 
    if (k.yi >= 1) {
 
@@ -744,7 +745,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
       fit.stats <- matrix(c(ll.ML, dev.ML, AIC.ML, BIC.ML, AICc.ML, ll.REML, dev.REML, AIC.REML, BIC.REML, AICc.REML), ncol=2, byrow=FALSE)
 
    } else {
-      fit.stats <- matrix(NA, nrow=5, ncol=2, byrow=FALSE)
+      fit.stats <- matrix(NA_real_, nrow=5, ncol=2, byrow=FALSE)
    }
 
    dimnames(fit.stats) <- list(c("ll","dev","AIC","BIC","AICc"), c("ML","REML"))
@@ -772,7 +773,7 @@ correct=TRUE, level=95, verbose=FALSE, digits, ...) {
    method    <- "FE"
    weighted  <- TRUE
    test      <- "z"
-   ddf       <- NA
+   ddf       <- NA_integer_
 
    if (is.null(ddd$outlist) || ddd$outlist == "nodata") {
 
