@@ -1,6 +1,6 @@
 vcov.matreg <- function(object, ...) {
 
-   mstyle <- .get.mstyle("crayon" %in% .packages())
+   mstyle <- .get.mstyle()
 
    .chkclass(class(object), must="matreg")
 
